Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/lis3mdl_simpletest.py
    :caption: examples/lis3mdl_simpletest.py
    :linenos:


Compass Example
---------------

Use the magnetometer to calculate compass headings.

.. literalinclude:: ../examples/lis3mdl_compass.py
    :caption: examples/lis3mdl_compass.py
    :linenos:


Data Rate Example
-----------------

Test each data rate

.. literalinclude:: ../examples/lis3mdl_data_rate_test.py
    :caption: examples/lis3mdl_data_rate_test.py
    :linenos:


LSM6DS Test
---------------

Test the LSM6DS device

.. literalinclude:: ../examples/lis3mdl_lsm6ds_test.py
    :caption: examples/lis3mdl_lsm6ds_test.py
    :linenos:

Range Test
---------------

Test each range

.. literalinclude:: ../examples/lis3mdl_range_test.py
    :caption: examples/lis3mdl_range_test.py
    :linenos:
